@@ -10,7 +10,7 @@
     m2 <- -bicenter.wt(distmat * distmat)
     m2 <- rbind(m2, 2 * bicenter.wt(distmat))
     m1 <- cbind(m1, m2)
-    lambda <- eigen(m1, only = TRUE)$values
+    lambda <- La.eigen(m1, only = TRUE)$values
     c <- max(Re(lambda)[Im(lambda) < 1e-08])
     if (print) 
         cat(paste("Cailliez constant =", round(c, dig = 5), "\n"))
